@@ -9,6 +9,8 @@ from array import array
 
 from dwca.rows import CoreRow, ExtensionRow
 
+# TODO: create text representation for those objects for easier debugging (avoid [<dwca.files.CSVDataFile object at 0x10c28d9d0>, <dwca.files.CSVDataFile object at 0x10c28da50>])
+
 
 class CSVDataFile(object):
     """Object used to access a DwCA-enclosed CSV data file.
@@ -20,16 +22,17 @@ class CSVDataFile(object):
 
     The file content can be accessed:
 
-    * By iterating on this object
-    * With :meth:`get_row_by_position`
-    * With :meth:`get_all_rows_by_coreid` (extensions data file only)
+    * By iterating on this object: a str (Python 3) or unicode (Python 2) is returned, including separators.
+    * With :meth:`get_row_by_position` (A :class:`dwca.rows.CoreRow` or :class:`dwca.rows.ExtensionRow` object is \
+    returned)
+    * For an extension data file, with :meth:`get_all_rows_by_coreid` (A :class:`dwca.rows.CoreRow` or \
+    :class:`dwca.rows.ExtensionRow` object is returned)
 
     On initialization, an index of new lines is build. This may take time, but makes random access\
     faster.
     """
 
-    # TODO: Test this class
-    # Not done yet cause issues there will probably make DwCAReader tests fails anyway
+    # TODO: More tests for this class
     def __init__(self, work_directory, file_descriptor):
         """Initialize the CSVDataFile object."""
         #: An instance of :class:`dwca.descriptors.DataFileDescriptor`, as given to the
@@ -51,6 +54,8 @@ class CSVDataFile(object):
         #: Number of lines to ignore (header lines) in the CSV file.
         self.lines_to_ignore = self.file_descriptor.lines_to_ignore
 
+        self._coreid_index = None
+
     def _position_file_after_header(self):
         self._file_stream.seek(0, 0)
         if self.lines_to_ignore > 0:
@@ -64,48 +69,72 @@ class CSVDataFile(object):
         return self.next()
 
     def next(self):  # NOQA
-        for line in self._file_stream:
-            return line
+        for row in self._file_stream:
+            return row
 
         raise StopIteration
 
-    # Returns a index of the per core_id positions of Rows in the file:
-    # {core_id1: []}
+    @property
+    def coreid_index(self):
+        """An index of the core rows referenced by this data file.
+
+        It is a Python dict such as:
+        ::
+        
+            { 
+            core_id1: [1],    # Row at position 1 references a Core Row whose ID is core_id1 
+            core_id2: [8, 10] # Rows at position 8 and 10 references a Core Row whose ID is core_id2
+            }
+
+        :raises: AttributeError if accessed on a core data file.
+
+        .. warning::
+
+            coreid_index is only available for extension data files.
+
+        .. warning::
+
+            Creating this index can be time and memory consuming for large archives, so it's created on the fly
+            at first access.
+        """
+        if self.file_descriptor.represents_corefile:
+            raise AttributeError('coreid_index is only available for extension data files')
+
+        if self._coreid_index is None:
+            self._coreid_index = self._build_coreid_index()
+
+        return self._coreid_index
 
-    # TODO: Generalize this so we can create indexes on any field ?
     def _build_coreid_index(self):
+        """Build and return an index of Core Rows IDs suitable for `CSVDataFile.coreid_index`."""
         index = {}
-        pos = 0
-        for l in self:
-            tmp = ExtensionRow(l, self.file_descriptor)
-            if tmp.core_id not in index:
-                index[tmp.core_id] = [pos]
-            else:
-                index[tmp.core_id].append(pos)
 
-            pos = pos + 1
+        for position, row in enumerate(self):
+            tmp = ExtensionRow(row, position, self.file_descriptor)
+            index.setdefault(tmp.core_id, []).append(position)
+
         return index
 
     # TODO: For ExtensionRow and a specific field only, generalize ?
     # TODO: What happens if called on a Core Row?
     def get_all_rows_by_coreid(self, core_id):
         """Return a list of :class:`dwca.rows.ExtensionRow` whose Core Id field match `core_id`."""
-        if not hasattr(self, '_coreid_index'):
-            self._coreid_index = self._build_coreid_index()
-
-        if core_id not in self._coreid_index:
+        if core_id not in self.coreid_index:
             return []
         else:
-            return [self.get_row_by_position(p) for p in self._coreid_index[core_id]]
+            return [self.get_row_by_position(p) for p in self.coreid_index[core_id]]
 
     def get_row_by_position(self, position):
-        """Return the row at `position` in the file."""
+        """Return the row at `position` in the file.
+
+        Header lines are ignored.
+        """
         try:
             l = self._get_line_by_position(position)
             if self.file_descriptor.represents_corefile:
-                return CoreRow(l, self.file_descriptor)
+                return CoreRow(l, position, self.file_descriptor)
             else:
-                return ExtensionRow(l, self.file_descriptor)
+                return ExtensionRow(l, position, self.file_descriptor)
         except IndexError:
             return None
 
@@ -114,9 +143,11 @@ class CSVDataFile(object):
         self._file_stream.seek(self._line_offsets[position + self.lines_to_ignore], 0)
         return self._file_stream.readline()
 
-    # TODO: test this method
     def close(self):
-        """Close the file."""
+        """Close the file.
+
+        The content of the file will not be accessible in any way afterwards.
+        """
         self._file_stream.close()
 
 
@@ -132,7 +163,7 @@ def _get_all_line_offsets(f, encoding):
     """
     f.seek(0, 0)
 
-    # We use an array of Longs instead of a basic list to store the index.
+    # We use an array of Longs instead of a list to store the index.
     # It's much more memory efficient, and a few tests w/ 1-4Gb uncompressed archives
     # didn't shown any significant slowdown.
     #
