@@ -2,6 +2,8 @@
 
 """This module provides objects that represents data rows coming from DarwinCore Archive."""
 
+import csv
+import sys
 from dwca.exceptions import InvalidArchive
 
 
@@ -16,6 +18,7 @@ class Row(object):
     def _build_str(self, source_str, id_str):
         txt = ("--\n"
                "Rowtype: {rowtype}\n"
+               "Position: {position}\n"
                "Source: {source_str}\n"
                "{id_row}\n"
                "Reference extension rows: {extension_flag}\n"
@@ -31,32 +34,33 @@ class Row(object):
             source_metadata_flag = 'No'
 
         return txt.format(rowtype=self.rowtype,
+                          position=self.position,
                           source_str=source_str,
                           data=self.data,
                           id_row=id_str,
                           extension_flag=extension_flag,
                           source_metadata_flag=source_metadata_flag)
 
-    def __init__(self, csv_line, descriptor):
+    def __init__(self, csv_line, position, descriptor):
         #: An instance of :class:`dwca.descriptors.DataFileDescriptor` describing the originating
         #: data file.
         self.descriptor = descriptor
 
+        #: The row position/index (starting at 0) in the source data file. This can be used, for example with
+        #: :meth:`DwCAReader.get_corerow_by_position` or :meth:`CSVDataFile.get_row_by_position`.
+        self.position = position
+
         #: The csv line type as stated in the archive descriptor.
         #: Examples: http://rs.tdwg.org/dwc/terms/Occurrence,
         #: http://rs.gbif.org/terms/1.0/VernacularName, ...
         self.rowtype = self.descriptor.type
 
-        line_ending = self.descriptor.lines_terminated_by
-        field_ending = self.descriptor.fields_terminated_by
-
-        fields_enclosed_by = self.descriptor.fields_enclosed_by
-
         # self.raw_fields is a list of the csv_line's content
         #:
-        self.raw_fields = []
-        for f in csv_line.rstrip(line_ending).split(field_ending):
-            self.raw_fields.append(f.strip(fields_enclosed_by))
+        self.raw_fields = csv_line_to_fields(csv_line,
+                                             line_ending=self.descriptor.lines_terminated_by,
+                                             field_ending=self.descriptor.fields_terminated_by,
+                                             fields_enclosed_by=self.descriptor.fields_enclosed_by)
 
         # TODO: raw_fields is a new property: to test
 
@@ -94,16 +98,16 @@ class CoreRow(Row):
     """This class is used to represent a row/line from a Darwin Core Archive data core file.
 
     You probably won't instantiate it manually but rather obtain it trough :class:`read.DwCAReader`
-    or :class:`read.GBIFResultsReader` (by iterating, using the rows attribute, get_row_by_index,
-    get_row_by_id, ...).
+    or :class:`read.GBIFResultsReader` (by iterating, using the rows attribute, get_corerow_by_position(),
+    get_corerow_by_id(), ...).
     """
 
     def __str__(self):
         id_str = "Row id: " + str(self.id)
         return super(CoreRow, self)._build_str("Core file", id_str)
 
-    def __init__(self, line, section_descriptor):
-        super(CoreRow, self).__init__(line, section_descriptor)
+    def __init__(self, line, position, section_descriptor):
+        super(CoreRow, self).__init__(line, position, section_descriptor)
 
         #: The row id (from the data file).
         if self.descriptor.id_index is not None:
@@ -132,8 +136,8 @@ class CoreRow(Row):
             m = None
 
         #: Row-level metadata (if provided by the archive).
-        #: This is a non-standard feature currently only provided when using
-        #: :class:`dwca.read.GBIFResultsReader`.
+        #: This is a non-standard DwCA feature currently that we can sometimes encounter (in downloads from GBIF.org
+        #: for example).
         self.source_metadata = m
 
     def link_extension_files(self, extension_data_files):
@@ -155,7 +159,7 @@ class CoreRow(Row):
     def __key(self):
         """Return a tuple representing the row. Common ground between equality and hash."""
         return (self.descriptor, self.id, self.data, self.extensions, self.source_metadata,
-                self.rowtype, self.raw_fields)
+                self.rowtype, self.raw_fields, self.position)
 
     def __eq__(self, other):
         return self.__key() == other.__key()
@@ -178,15 +182,15 @@ class ExtensionRow(Row):
         id_str = "Core row id: " + str(self.core_id)
         return super(ExtensionRow, self)._build_str("Extension file", id_str)
 
-    def __init__(self, line, descriptor):
-        super(ExtensionRow, self).__init__(line, descriptor)
+    def __init__(self, line, position, descriptor):
+        super(ExtensionRow, self).__init__(line, position, descriptor)
 
         #: The id of the core row this extension is reffering to.
         self.core_id = self.raw_fields[descriptor.coreid_index]
 
     def __key(self):
         """Return a tuple representing the row. Common ground between equality and hash."""
-        return (self.descriptor, self.core_id, self.data, self.rowtype, self.raw_fields)
+        return (self.descriptor, self.core_id, self.data, self.rowtype, self.raw_fields, self.position)
 
     def __eq__(self, other):
         return self.__key() == other.__key()
@@ -196,3 +200,33 @@ class ExtensionRow(Row):
 
     def __hash__(self):
         return hash(self.__key())
+
+
+def csv_line_to_fields(csv_line, line_ending, field_ending, fields_enclosed_by):
+    """Split a line from a CSV file.
+
+    Return a list of fields. Content is not trimmed.
+    """
+    csv_line = csv_line.rstrip(line_ending)
+    raw_fields = []
+    if sys.version_info[0] < 3:
+        if isinstance(csv_line, unicode):
+            csv_line = csv_line.encode('utf8')
+        if isinstance(field_ending, unicode):
+            field_ending = field_ending.encode('utf8')
+        if isinstance(fields_enclosed_by, unicode):
+            fields_enclosed_by = fields_enclosed_by.encode('utf8')
+
+    if fields_enclosed_by == "":
+        opts = {'quoting': csv.QUOTE_NONE}
+    else:
+        opts = {'quoting': csv.QUOTE_ALL,
+                'quotechar': fields_enclosed_by}
+
+    for row in csv.reader([csv_line], delimiter=field_ending, **opts):
+        for f in row:
+            field = f.strip(fields_enclosed_by)
+            if sys.version_info[0] < 3:
+                field = field.decode('utf8')
+            raw_fields.append(field)
+    return raw_fields
\ No newline at end of file
