@@ -19,6 +19,7 @@ MULTIEXTENSIONS_ARCHIVE_PATH = _sample_data_path('dwca-2extensions.zip')
 IDS_ARCHIVE_PATH = _sample_data_path('dwca-ids.zip')
 UTF8EOL_ARCHIVE_PATH = _sample_data_path('dwca-utf8-eol-test.zip')
 DIRECTORY_ARCHIVE_PATH = _sample_data_path('dwca-simple-dir')
+DIRECTORY_CSV_QUOTE_ARCHIVE_PATH = _sample_data_path('dwca-csv-quote-dir')
 DEFAULT_META_VALUES = _sample_data_path('dwca-meta-default-values')
 INVALID_LACKS_METADATA = _sample_data_path('dwca-invalid-lacks-metadata')
 MISSINGMETA_PATH = _sample_data_path('gbif-results-lacks-s-metadata.zip')
@@ -33,3 +34,4 @@ NOMETADATA_PATH = _sample_data_path('dwca-nometadata.zip')
 DEFAULT_METADATA_FILENAME = _sample_data_path('dwca-default-metadata-filename.zip')
 BASIC_ARCHIVE_TGZ_PATH = _sample_data_path('dwca-simple-test-archive.tgz')
 INVALID_DESCRIPTOR = _sample_data_path('dwca-malformed-descriptor')
+DWCA_ORPHANED_ROWS = _sample_data_path('dwca-orphaned-rows.zip')
